@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -16,7 +16,6 @@ BEGIN {
 		scope => sub {
 			my ($caller, $self, %props) = @_;
 			for my $prop (keys %{$props{properties}}) {
-				#$props{properties}->{$prop} = {%{$props{properties}{$prop}}};
 				if ($props{properties}{$prop}{value} && ref $props{properties}{$prop}{value} eq 'CODE') {
 					my $cb = $props{properties}{$prop}{value};
 					$props{properties}{$prop}{value} = sub { $cb->($META{initialised}{$caller}{${$self}->{identifier}}, @_) };
@@ -61,7 +60,8 @@ BEGIN {
 						$props{properties}{$prop}{$_} = sub {
 							my (@params) = @_;
 							for (my $i = 0; $i < scalar @{$mod} - 1; $i++) {
-								@params = ($cb->($mod->[$i], @params));
+								my @new_params = ($cb->($mod->[$i], @params));
+								@params = @new_params if @new_params;
 							}
 							return $cb->($mod->[-1], @params);
 						};
@@ -412,7 +412,7 @@ sub import {
 	}
 
 	$PRO{keyword}($caller, '(bool', sub { scalar keys %{${$_[0]}->{prototype}}; });
-	$PRO{keyword}($caller, '((', sub {});
+	$PRO{keyword}($caller, '((', sub { });
 	$PRO{keyword}($caller, '(%{}', sub {
 		${$_[0]}->{prototype};
 	});
@@ -483,6 +483,11 @@ sub clear_meta {
 	};
 }
 
+sub clear_property {
+	my ($self, $name, $prop) = @_;
+	delete $META{$name}{properties}{$prop};
+}
+
 1;
 
 __END__
@@ -493,7 +498,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
@@ -932,6 +937,71 @@ Extend or redefine an object meta definition.
 
 	1;
 
+=head2 FACTORY AND CHAINS
+
+With Rope you can also create chained and factory properties. A chained property is where you define several code blocks to be called in order that you define, they effectively hook into the Rope cores 'after' callback. A factory sub allows you to define a property which will react based upon the passed in parameters. Factories and Chains can be used in conjunction, the following is and example of a factory into a chain.
+
+	package Church;
+
+	use Rope;
+	use Rope::Autoload;
+	use Rope::Factory qw/Str/;
+	use Rope::Chain;
+
+	prototyped (
+		been_cannot_find => [],
+		found => []
+	);
+
+	function reset => sub {
+		$_[0]->been_cannot_find = [];
+		$_[0]->found = [];	
+	};
+
+	factory add => (
+		[Str] => sub {
+			$_[0]->reset() if $_[1] eq 'reset';
+		},
+		[Str, Str] => sub {
+			$_[0]->reset() if $_[1] eq 'reset';
+			push @{$_[0]->found}, $_[2];
+		}
+	);
+
+	chain add => 'ephesus' => sub {
+		push @{ $_[0]->been_cannot_find }, 'Ephesus';
+		return;
+	};
+ 
+	chain add => 'smyrna' => sub {
+		push @{ $_[0]->been_cannot_find }, 'Smyrna';
+		return;
+	};
+	 
+	chain add => 'pergamon' => sub {
+		push @{ $_[0]->been_cannot_find }, 'Pergamon';
+		return;
+	};
+
+	chain add => 'thyatira' => sub {
+		push @{ $_[0]->been_cannot_find }, 'Thyatira';
+		return $_[0]->been_cannot_find;
+	};
+
+	...
+
+	my $asia = Church->new();
+
+	$asia->add('reset');
+
+	$asia->add('reset', 'House of Mary');
+
+	$asia->reset();
+
+	$asia->thyatira();
+
+Notes: If you chain into a factory, the factory will accept not the passed params but the response from the 'last' chain. Returning undef is a hack that only works when chaining a chain, your first defined chain in this approach should return either the passed request params or some valid response. Factories cannot currently handle 'undef' explicitly but this may change in the future. If you define multiple factories with the same name, the initial will be extended not re-written, so extending a factory or chain should work accross inheritance.
+
 =head1 AUTOLOADING
 
 If you do not enjoy accessing properties as hash keys and would instead like to access them as package routines then you can simply include C<Rope::Autoload> and this will use perls internal AUTOLOAD functionality to expose your properties as routines.
