@@ -20,27 +20,39 @@ sub import {
 	if (@types) {	
 		Coerce::Types::Standard->import::into($caller, @types)
 	}
-	my $any = Any;
 	$PRO{keyword}($caller, 'factory', sub {
 		my ($name, @factory) = @_;
-		my ($meta, $fact, $exists) = (Rope->get_meta($caller));
+		my ($meta, $fact, $exists, $extends) = (Rope->get_meta($caller));
 		if ($meta->{properties}->{$name}) {
-			$fact = $meta->{properties}->{$name}->{fact};
-			$exists = 1;
+			if ($meta->{properties}->{$name}->{fact}) {
+				$fact = $meta->{properties}->{$name}->{fact};
+				$exists = 1;
+			} else {
+				$fact = Factory::Sub->new();
+				$extends = 1;
+			}
 		} else {
 			$fact = Factory::Sub->new();
 		}
 		while (@factory) {
 			my ($check, $cb) = (shift(@factory), shift(@factory)); 
-			$fact->add(sub { 1 }, @{$check}, $cb);
+			$fact->add(sub { $_[0];  }, @{$check}, $cb);
+		}
+		if ($extends) {
+			Rope->clear_property($caller, $name);
+			my $prop = $meta->{properties}->{$name};
+			$prop->{fact} = $fact;
+			push @{$prop->{after}}, sub { $fact->(@_) };
+			$caller->property($name, %{$prop});	
+		} elsif (!$exists) {
+			$caller->property($name,
+				value => sub { $fact->(@_) },
+				initable => 0,
+				enumerable => 0,
+				writeable => 0,
+				fact => $fact
+			);
 		}
-		$caller->property($name,
-			value => sub { $fact->(@_) },
-			initable => 0,
-			enumerable => 0,
-			writeable => 0,
-			fact => $fact
-		) if !$exists;
 	});
 }
 
@@ -54,7 +66,7 @@ Rope::Factory - Rope factory properties
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
